@@ -65,9 +65,10 @@ class geonamesDownloader(Thread):
         print "geonames downolad res(",len(self.geonames.poi),")"
         if len(self.geonames.poi) == 1:
             self.geonames.osmMapa.show_find_results.append( self.geonames.poi[0] )
-            self.geonames.osmMapa.recalculate_center_and_zoom()
+            #self.geonames.osmMapa.recalculate_center_and_zoom()
             print "geonames add marker"
         print "goanames DONE"
+        self.geonames.ui_thread = 2
 
 
 
@@ -108,6 +109,7 @@ class google_geonames:
 
     def search_query(self, str):
         # TODO
+        self.ui_thread = 1
         self.poi = []
         self.CONFIG['google_geonames_search'] = str
         t = geonamesDownloader( self, self.CONFIG['google_geonames_search'])
