@@ -120,7 +120,8 @@ class MyZoomSelect(hildon.Dialog):
         self.h_max.set_value(16)
         self.vbox.pack_start( self.h_max, True,True,0)
 
-        bt_download = gtk.Button("Download")
+        bt_download = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Download")
         bt_download.connect("clicked", self.act_download)
         self.vbox.pack_start( bt_download, True, True, 0)
 
@@ -331,13 +332,15 @@ class gpx_tracks:
         bt_offline.set_label("work offline")
         vbox.pack_start(bt_offline, pack)
 
-        bt_load = gtk.Button("Load track")
+        bt_load = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Load track")
         bt_load.connect("clicked", self.on_load, dialog,bt_offline)
         vbox.pack_start(bt_load,pack)
 
         hbox.pack_start( vbox, pack)
 
-        bt_clear = gtk.Button("Clear tracks")
+        bt_clear = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear tracks")
         bt_clear.connect("clicked", self.on_clean, dialog)
         hbox.pack_start(bt_clear,pack)
 
