@@ -64,7 +64,13 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
+0.19-8
+    set max clouds on screen
+    plugin[google_routesearch] when don't speak street names parse one more time for html tags :/
+        auto recalculation step by 50m. start from 50m
+    plugin[google_places] new plugin :)
 0.19-7
+
     plugin[google_routesearch] as a stand alone plugin on left menu
         speak or not speak street names :)
         ui clean up
@@ -1375,6 +1381,7 @@ class UI(gtk.Window):
         else:
             make_from = self.markers
 
+        icons_on_screen = 0
         for m in make_from:
             lt = m[0]
             ln = m[1]
@@ -1382,7 +1389,9 @@ class UI(gtk.Window):
                 if not m[5]:
                     m[5] = self.osm.image_add( lt, ln, m[4] )
                 if zoom>10 and m[3]:
-                    self.draw_cloud_byll(cr, lt, ln, m[3])
+                    if icons_on_screen < 8:
+                        icons_on_screen+=1
+                        self.draw_cloud_byll(cr, lt, ln, m[3])
             else:
                 if m[5]:
                     self.osm.image_remove(m[5])
